const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-BeSE_9n5.js","assets/workspaceStore-BvulFVND.js","assets/jwt-decode.esm-w98cnxsx.js","assets/jwt-decode-D9e-DIPp.css","assets/userStore-RytD6Y-k.js","assets/url-BvgxDhBd.js","assets/colorHelpers-DqsBXz4v.js","assets/OidcLogoutCallback-D90oP1sG.js","assets/Login-Cd7u0Aj6.js","assets/Login.vue_vue_type_script_setup_true_lang-DR9oBhLg.js","assets/OTPInput-DSXr6Xzp.js","assets/OTPInput-C8ldH5jb.css","assets/Logo-BW1YxY_x.js","assets/Logo-D2kepPyK.css","assets/string-EvDoB2m0.js","assets/CircularLoading-D9QcXy0g.js","assets/CircularLoading-BiyobKo3.css","assets/index-8betguO_.js","assets/Login-cMuNqCbG.css","assets/Login-C1k-SC0u.css","assets/Main-DmUMAphr.js","assets/PlayerNavbar-DE7Hv2v_.js","assets/metadata-Cbf2QfTi.js","assets/PhMagnifyingGlass.vue-_eaoU8ui.js","assets/PhWebhooksLogo.vue-DhFlb9oJ.js","assets/LoadingOutlined-MWb1b_T4.js","assets/PhSignOut.vue-sSjK7Lry.js","assets/index-dx-DZEmM.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-cPL-y_2R.js","assets/Watermark-a9ExFmvp.js","assets/constants-SdFWGN9z.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-DkPfydpB.js","assets/index-DBNlcUI4.js","assets/Home-B6UGln4L.css","assets/Error-Dmwgt4iI.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-Ke1J5HF0.js","assets/Error-CIbhyrKS.css","assets/Form-DxK2_bYu.js","assets/FormRunner-D6aPvvWB.js","assets/Steps-DjJVDWUk.js","assets/index-BxcoxSO2.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-61-wByB6.css","assets/redirect-CdY14jPx.js","assets/asyncComputed-C3zJw6wt.js","assets/uuid-D0NPrCdZ.js","assets/Form-A1oa-Q46.css"])))=>i.map(i=>d[i]);
import{ag as c,ah as d,ad as t,ai as m}from"./jwt-decode.esm-w98cnxsx.js";import{a as u}from"./workspaceStore-BvulFVND.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="842912e0-f6bd-4239-9684-308de6f59be6",a._sentryDebugIdIdentifier="sentry-dbid-842912e0-f6bd-4239-9684-308de6f59be6")}catch{}})();const f=async()=>{try{const a=await fetch("/_editor/api/workspace/version");return a.ok&&(await a.json()).version||"8ca68f5786865ac46aab610bc7527b2b244f0a8e"}catch(a){return console.error("Failed to fetch Abstra version:",a),"8ca68f5786865ac46aab610bc7527b2b244f0a8e"}},p=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-BeSE_9n5.js"),__vite__mapDeps([0,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-D90oP1sG.js"),__vite__mapDeps([7,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-Cd7u0Aj6.js"),__vite__mapDeps([8,9,2,3,1,4,5,6,10,11,12,13,14,15,16,17,18,19])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-DmUMAphr.js"),__vite__mapDeps([20,21,4,2,3,1,5,6,22,23,24,25,26,27,28,29])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-cPL-y_2R.js"),__vite__mapDeps([30,22,2,3,23,24,31,1,4,5,6,32,33,34,35,25,36])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-Dmwgt4iI.js"),__vite__mapDeps([37,38,12,2,3,13,32,1,4,5,6,35,39])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-DxK2_bYu.js"),__vite__mapDeps([40,4,2,3,41,9,1,5,6,10,11,12,13,14,15,16,17,18,42,43,44,31,32,33,45,46,47,48,49])),meta:{hideLogin:!0}}]}],o=c({history:d("/"),routes:p,scrollBehavior(a){if(a.hash)return{el:a.hash}}}),l=a=>async(e,r)=>{if(m(e,r),e.meta.allowUnauthenticated)return;const n=await u(e.path),{redirect:i,...s}=e.query;switch(n.status){case"ALLOWED":break;case"UNAUTHORIZED":await a.push({name:"playerLogin",query:{...s,redirect:i||e.path},params:e.params});break;case"NOT_FOUND":await a.push({name:"error",params:{status:"404"}});break;default:await a.push({name:"error",params:{status:"403"}})}};o.beforeEach(l(o));export{p as a,l as b,f as g,o as r};
//# sourceMappingURL=router-5_T97tqf.js.map
