import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-DofsrAD7.js";import{a as i,ac as s,p as a,e as m,u as c}from"./jwt-decode.esm-w98cnxsx.js";import"./router-CTS6LGA3.js";import"./ts.worker-7e5L8cGr.js";import"./fetch-df_ec0wX.js";import"./record-DvE-f8u-.js";import"./SaveButton-Bk3ytAro.js";import"./ExclamationCircleOutlined-ByzGmSJp.js";import"./CrudView-DpmVvcTJ.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-7B6zrrQe.js";import"./constants-SdFWGN9z.js";import"./url-BvgxDhBd.js";import"./PhDotsThreeVertical.vue-CSDbCFi2.js";import"./index-D-gJj41F.js";import"./asyncComputed-C3zJw6wt.js";import"./omniChatStore-DMwxHQxl.js";import"./uuid-D0NPrCdZ.js";import"./PhCopySimple.vue-C3TigkLW.js";import"./PhPencil.vue-B1NFOvlF.js";import"./useCodebaseEvents-CxvwnKP9.js";import"./contracts.generated-DgKaNbvc.js";import"./index-8betguO_.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="230ca48c-a644-4640-8542-45412115e5ee",o._sentryDebugIdIdentifier="sentry-dbid-230ca48c-a644-4640-8542-45412115e5ee")}catch{}})();const A=i({__name:"EnvVars",setup(o){const r=s().params.projectId,t=new p(r);return(d,u)=>(m(),a(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-Bd8kn_6W.js.map
